==> apache-carbondata-1.5.4-source-release.zip: carbondata-parent-1.5.4/processing/src/main/java/org/apache/carbondata/processing/sort/DummyRowUpdater.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.carbondata.processing.sort;

import org.apache.carbondata.core.datastore.row.WriteStepRowUtil;
import org.apache.carbondata.processing.loading.row.IntermediateSortTempRow;

/**
 * This class will be used when order is not change so not need to update the row
 */
public class DummyRowUpdater implements SortTempRowUpdater {

  private static final long serialVersionUID = 5989093890994039617L;

  @Override public void updateSortTempRow(IntermediateSortTempRow intermediateSortTempRow) {
    // DO NOTHING
  }

  @Override public void updateOutputRow(Object[] out, int[] dimArray, Object[] noDictArray,
      Object[] measureArray) {
    out[WriteStepRowUtil.DICTIONARY_DIMENSION] = dimArray;
    out[WriteStepRowUtil.NO_DICTIONARY_AND_COMPLEX] = noDictArray;
    out[WriteStepRowUtil.MEASURE] = measureArray;
  }
}

==> apache-carbondata-2.3.0-source-release.zip: carbondata-parent-2.3.0/processing/src/main/java/org/apache/carbondata/processing/sort/DummyRowUpdater.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.carbondata.processing.sort;

import org.apache.carbondata.core.datastore.row.WriteStepRowUtil;
import org.apache.carbondata.processing.loading.row.IntermediateSortTempRow;

/**
 * This class will be used when order is not change so not need to update the row
 */
public class DummyRowUpdater implements SortTempRowUpdater {

  private static final long serialVersionUID = 5989093890994039617L;

  @Override
  public void updateSortTempRow(IntermediateSortTempRow intermediateSortTempRow) {
    // DO NOTHING
  }

  @Override
  public void updateOutputRow(Object[] out, int[] dimArray, Object[] noDictArray,
      Object[] measureArray) {
    out[WriteStepRowUtil.DICTIONARY_DIMENSION] = dimArray;
    out[WriteStepRowUtil.NO_DICTIONARY_AND_COMPLEX] = noDictArray;
    out[WriteStepRowUtil.MEASURE] = measureArray;
  }
}
